@@ -1,5 +1,5 @@
 
-.get.mpt.model <- function (model.filename, model.type){
+.get.mpt.model <- function (model.filename, model.type, model.check = TRUE){
 	
 	if ("connection" %in% class(model.filename)) model <- .read.MPT.model(model.filename)
 	else {
@@ -11,6 +11,6 @@
 	)
 	}
 	prob.tree.check <- .check.MPT.probabilities(model)
-	if(!(all(prob.tree.check==1))) stop(paste("Model not constructed well: Branch probabilities of tree(s) ", paste(which(prob.tree.check!=1), collapse= ", "), " do not sum to 1!", sep = ""))
-	else return (model)
+	if (model.check) if(isTRUE(!(all(prob.tree.check==1)))) stop(paste("Model not constructed well: Branch probabilities of tree(s) ", paste(which(prob.tree.check!=1), collapse= ", "), " do not sum to 1!", sep = ""))
+	return (model)
 }
